import React, { useEffect, useState } from "react";
import { Card, Col, Container, Row, Button } from "react-bootstrap";
import { Link } from "react-router-dom";
import CategoryDataAccess from "dataAccess/categoryDataAccess";
import { connect, useDispatch } from "react-redux";
import { actions as categoryActions } from "@redux/categoryRedux";
import SpinnerLocal from "../spinner";

const ViewAllCategory = (props: any) => {
    const dispatch = useDispatch();

    useEffect(() => {
        dispatch(categoryActions.getAllCategories());
    }, [dispatch]);

  if (props.category.allCategory.length === 0) {
    return <SpinnerLocal height="75vh"/>;
  }
  return (
    <div className="new-category-design">
      <Container fluid>
        <Row className="top border-bottom">
          <Col xl={4} lg={4} md={12} sm={12} xs={12}>
              <h4 className="top-title"> All Categories </h4>
          </Col>
        </Row>
        <Row className="responsive-card">
          {props.category.allCategory.length !== 0 &&
            props.category.allCategory.map((category) => {
              return (
                  <Col xl={2} lg={3} md={4} sm={9} xs={10}>
                    <Link
                      to={"/category/subcategory/" + category.slug}
                      className="offer-image-link">
                        <Card className="card-offer">
                          <img
                            src={category.image==null? "images/health.png" : category.image}
                            className="offer-image"
                            alt=""
                            style={{ margin:"auto", width:"50px", height:"50px", marginTop:"30px", marginBottom:"20px", }}
                          />
                         
                          <Card.Body>
                            <Card.Title className="offer-card-title">
                              {category.name.length > 20 ? (
                                <p className="card-product-name">
                                  {category.name.substring(0, 22) + "..."}
                                </p>
                              ) : (
                                <p className="card-product-name">{category.name}</p>
                              )}
                            </Card.Title>
                          </Card.Body>
                        </Card>
                    </Link>
                  </Col>
              );
            })}


            {!props.category.allCategoryLoading &&
              props.category.allCategoryInfo.last_page &&
              props.category.allCategoryInfo.current_page !==
                props.category.allCategoryInfo.last_page && (
                <Row style={{ textAlign: "center", marginTop: "20px" }}>
                  <Col>
                    <Button
                      className="load-more"
                      variant="primary"
                      onClick={() => {
                        dispatch(categoryActions.getAllCategories(props.category.allCategoryInfo.current_page + 1));
                      }}
                    >
                      <span className="btn-text">Load more</span>
                    </Button>
                  </Col>
                </Row>
              )}

            {/*  Loading... */}
            {props.category.allCategoryLoading && (
                <SpinnerLocal height="15vh"/>
            )}


        </Row>
      </Container>
    </div>
  );
};

const mapStateToProps = ({ category }) => { return { category }; };
export default connect(mapStateToProps)(ViewAllCategory);